@@ -116,6 +116,7 @@ wtbl_init_from_config (void)
   GTokenValue *val;
   gint drvr_id;
   gboolean retval;
+  char *s;
 
   /* get wavetable sample caching config var (1 = on, 0 = off, 2 = auto) */
   wtbl_cache_samples =
@@ -124,8 +125,12 @@ wtbl_init_from_config (void)
   /* Same OSS device is used for all OSS based wavetable/sequencer/midi
      drivers, load the config value here */
   if (wtbl_oss_devname) g_free (wtbl_oss_devname);
-  wtbl_oss_devname =
-    g_strdup(smurfcfg_get_val (SMURFCFG_WAVETBL_OSSDEV)->v_string);
+
+  s = smurfcfg_get_str (SMURFCFG_WAVETBL_OSSDEV);
+  if (!strlen (s))		/* if config has blank value, set to default */
+    s = "/dev/sequencer";
+
+  wtbl_oss_devname = g_strdup(s);
 
   val = smurfcfg_get_val (SMURFCFG_WAVETBL_DRIVER);
 
